.wf-panel .tray-button image,
.wf-panel image.launcher{
    transition: 500ms linear;
    -gtk-icon-transform: scale(0.8);
}

.wf-panel image.launcher:hover,
.wf-panel .tray-button:hover image {
    transition: 500ms linear;
    -gtk-icon-transform: scale(1.0);
}

/* FIXME: Makes a bad assumption about LTR reading direction. */
.wf-panel .battery label,
.wf-panel .battery:hover label,
.wf-panel .window-button label,
.wf-panel .window-button image,
.wf-panel .window-button:hover label,
.wf-panel .tray-button,
.wf-panel .tray-button:hover,
.wf-panel .notification button {
    padding-left: 5px;
}

.wf-panel .window-button.activated {
    background-color: #8883;
}

.wf-panel .window-button:hover {
    background-color: #8882;
}

.wf-panel .battery overlay label {
--bcol: rgb(from currentcolor calc(255 - r) calc(255 - g) calc(255 - b) );
text-shadow: 1px  1px 0 var(--bcol),
            -1px -1px 0 var(--bcol),
            -1px  1px 0 var(--bcol),
             1px -1px 0 var(--bcol),
             0px  1px 0 var(--bcol),
             0px -1px 0 var(--bcol),
            -1px  0px 0 var(--bcol),
             1px  0px 0 var(--bcol);
	font-weight:bold;
}

.wf-panel .notification .time {
    padding-left: 5px;
    padding-right: 5px;
}

.wf-panel .tray .tray-button:first-child,
.wf-panel .notification button:first-child {
    padding-left: 0px;
}

.wf-panel .weather image {
    -gtk-icon-size: 25px;
    padding-left: 4px;
    padding-right: 4px;
    padding-bottom: 4px;
}

.wf-panel .weather label {
    font-weight: bold;
    font-size: 20px;
}

.wf-panel .network label {
    padding-left: 6px;
}

.wf-panel .command-output.icon-left label {
    padding-left: 5px;
}

.wf-panel .command-output.icon-right label {
    padding-right: 5px;
}

.wf-panel .command-output.icon-top label {
    padding-top: 5px;
}

.wf-panel .command-output.icon-bottom label {
    padding-bottom: 5px;
}

.wf-panel .language {
    min-width: 48px;
}

.wf-panel label.language {
    background-color: #24283B;
    padding: 5px;
    margin: 5px;
    border-radius: 3px;
    color: #41A6B5;
}

.wf-panel .workspace-switcher {
    background-color: #222222FF;
    padding-top: 0px;
    padding-bottom: 1px;
    padding-right: 1px;
    padding-left: 0px;
}

.wf-panel .workspace-switcher .workspace.active {
    background-color: #005577FF;
    margin-top: 1px;
    margin-left: 1px;
}

.wf-panel .workspace-switcher .workspace.inactive {
    background-color: #0077AAFF;
    margin-top: 1px;
    margin-left: 1px;
}

.wf-panel .workspace-switcher .workspace .view {
    background-color: #0000AA77;
    border: 1px solid #222;
}

.wf-panel .workspace-switcher .workspace .view.active {
    background-color: #FF00AA77;
    border: 1px solid #222;
}

.wf-panel .workspace-switcher .workspace .view.inactive {
    background-color: #00FFAA77;
    border: 1px solid #222;
}

.wf-panel .wf-menu.selected {
    background-color:#8883;
}

.wf-panel .wf-menu:hover {
    background-color: #8882;
}

.excellent>label {
    color: #00ff00;
}

.good>label
{
    color: #88ff00;
}

.ok>label
{
    color: #ffff00;
}

.weak>label
{
    color: #ff8800;
}

.none>label
{
    color: #ff0000;
}
.bluetooth>label
{
    color: #8888ff;
}

.wf-dock,
.wf-dock .out-box {
    background: transparent;
}

.wf-dock .box {
    background-color: #33333355;
    padding-left: 1em;
    padding-right: 1em;
    border-radius: 1em;
}

.wf-dock button {
    background: transparent;
    padding-left: 0rem;
    padding-right: 0rem;
}

.wf-dock button.activated {
    border-bottom: 3px solid white;
    margin-bottom: 5px;
}

.wf-dock image {
    background: transparent;
    padding-left: 0rem;
    padding-right: 0rem;
    transition: 200ms;
    -gtk-icon-transform: scale(0.7);
}

.wf-dock image:hover {
    background: transparent;
    padding-left: 0rem;
    padding-right: 0rem;
    transition: 200ms;
    -gtk-icon-transform: scale(1.0);
}

.wf-dock image.toplevel-icon {
    animation-name: embiggen;
    animation-duration: 1000ms;
    animation-timing-function: linear;
    animation-iteration-count: 1;
}

.wf-dock .closing image {
    animation-name: kromulent;
    animation-duration: 1000ms;
    animation-timing-function: linear;
    animation-iteration-count: 1;
    animation-fill-mode: forwards;
}

.network-control-center image.access-point {
    -gtk-icon-size: 40px;
}

.network-control-center .access-point.secure .security {
    -gtk-icon-size:20px;
    color:red;
}


.network-control-center .access-point.secure.has-password .security {
    color:green;
}

.network-control-center .access-point.has-password{
  font-weight: bold;
  background: #8f83;
}

.network-control-center .vpn.active{
  font-weight: bold;
  background: #8f83;
}

.network-control-center .access-point .band {
    font-size: 1em;
    font-weight: bolder;
}

.wf-locker .password{
    padding: 10px;
    border-radius: 10px;
    background: #0004;
}
.wf-locker .fingerprint-overlay-image.good {
    color: #0f0;
}
.wf-locker .fingerprint-overlay-image.bad {
    color: #f00;
}
.wf-locker .fingerprint-overlay-image.info {
    color: #88f;
}
.wf-locker .user label {
    font-weight: bold;
    text-transform: capitalize;
}
.wf-locker image.weather {
    padding-left: 25px;
    padding-right: 25px;
    padding-bottom: 100px;
}

.wf-locker label.weather {
    font-weight: bold;
    padding-left: 100px;
    padding-bottom: 75px;
}
.wf-locker label.clock {
    font-weight: bold;
    padding-right: 100px;
    padding-bottom: 75px;
}

.wf-locker .failure {
    animation-name: shake;
    animation-duration:0.5s;
    animation-timing-function: linear;
    animation-iteration-count: 1;
    animation-fill-mode: forwards;
}

.wf-locker.sized-480 {
    font-size:6px;
}

.wf-locker.sized-720 {
    font-size:7px;
}

.wf-locker.sized-1080 {
    font-size:10px;
}

.wf-locker.sized-1440 {
    font-size:14px;
}

.wf-locker.sized-2160 {
    font-size:18px;
}

@keyframes embiggen {
    to {
        -gtk-icon-size: 64px;
        -gtk-icon-transform: translateY(0px);
        padding-left: 1rem;
        padding-right: 1rem;
    }

    from {
        -gtk-icon-size: 0px;
        -gtk-icon-transform: translateY(64px);
        padding-left: 0rem;
        padding-right: 0rem;
    }
}

@keyframes kromulent {
    from {
        -gtk-icon-size: 64px;
        -gtk-icon-transform: translateY(0px);
        padding-left: 1rem;
        padding-right: 1rem;
    }

    to {
        -gtk-icon-size: 0px;
        -gtk-icon-transform: translateY(64px);
        padding-left: 0rem;
        padding-right: 0rem;
    }
}

@keyframes shake {
  0% {
    transform: translateX(0px);
  }
  20% {
    transform: translateX(20px);
  }
  40% {
    transform: translateX(-20px);
  }
  60% {
    transform: translateX(20px);
  }
  80% {
    transform: translateX(-20px);
  }
  100% {
    transform: translateX(0px);
  }
}

